0.9.9 API documentation: spline.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

spline.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../glm.hpp"
17 #include "../gtx/optimum_pow.hpp"
18
19 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
20 # ifndef GLM_ENABLE_EXPERIMENTAL
21 # pragma message("GLM: GLM_GTX_spline is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
22 # else
23 # pragma message("GLM: GLM_GTX_spline extension included")
24 # endif
25 #endif
26
27 namespace glm
28 {
31
34 template<typename genType>
35 GLM_FUNC_DECL genType catmullRom(
36 genType const& v1,
37 genType const& v2,
38 genType const& v3,
39 genType const& v4,
40 typename genType::value_type const& s);
41
44 template<typename genType>
45 GLM_FUNC_DECL genType hermite(
46 genType const& v1,
47 genType const& t1,
48 genType const& v2,
49 genType const& t2,
50 typename genType::value_type const& s);
51
54 template<typename genType>
55 GLM_FUNC_DECL genType cubic(
56 genType const& v1,
57 genType const& v2,
58 genType const& v3,
59 genType const& v4,
60 typename genType::value_type const& s);
61
63 }//namespace glm
64
65 #include "spline.inl"
glm::hermite
GLM_FUNC_DECL genType hermite(genType const &v1, genType const &t1, genType const &v2, genType const &t2, typename genType::value_type const &s)
Return a point from a hermite curve.
glm::cubic
GLM_FUNC_DECL genType cubic(genType const &v1, genType const &v2, genType const &v3, genType const &v4, typename genType::value_type const &s)
Return a point from a cubic curve.
glm::catmullRom
GLM_FUNC_DECL genType catmullRom(genType const &v1, genType const &v2, genType const &v3, genType const &v4, typename genType::value_type const &s)
Return a point from a catmull rom curve.
glm
Definition: common.hpp:20